@@ -23,21 +23,25 @@ my @conn;
 my @coords= map [(int rand 500)+50,(int rand 300) +50],(0..4);
 my %command;
 $command{build_items}=sub{
-  for my $n(0..4){$node[$n] = Tk::GraphItems->TextBox(canvas=>$can,
-							  text=>"object $n",
-							  'x'=>\$coords[$n][0],
-							  'y'=>\$coords[$n][1]
-							 );
+    for my $n(0..4){
+	$node[$n] = Tk::GraphItems->TextBox(canvas => $can,
+					    text   => "object $n",
+					    'x'    => \$coords[$n][0],
+					    'y'    => \$coords[$n][1]
+					);
 		}
-  for my $n(0..4){$conn[$n] = Tk::GraphItems->Connector(
-						 source=>$node[$n],
-						 target=>$node[($n+1)%5],
-						 colour =>'black'
-						);
-		}
-
+  for my $n(0..4){
+      $conn[$n] = Tk::GraphItems->Connector(
+					    source => $node[$n],
+					    target => $node[($n+1)%5],
+					    colour => 'black'
+					);
+		} 
+  weaken $_ for(@conn) ;
+    
   $command{nodes_move}->();
-};
+}
+;
 my @step;
 my $repeat;
 my @borders = (25,25,575,375);
@@ -51,27 +55,28 @@ $command{nodes_move} = sub {
 };
 
 sub transform{
-  for my $n (0..4){
-    for (0,1){$coords[$n][$_] += $step[$n][$_];
-	      #print "$coords[$n][$_]\n";
-	    }
-    if ($coords[$n][0]>$borders[2]){
-      $step[$n][0]= - $step[$n][0];
-      $coords[$n][0] = $borders[2];
+    for my $n (0..4) {
+	for (0,1) {
+	    $coords[$n][$_] += $step[$n][$_];
+	    #print "$coords[$n][$_]\n";
+	}
+	if ($coords[$n][0]>$borders[2]) {
+	    $step[$n][0]= - $step[$n][0];
+	    $coords[$n][0] = $borders[2];
+	}
+	if ($coords[$n][0]<$borders[0]) {
+	    $step[$n][0]= - $step[$n][0];
+	    $coords[$n][0] = $borders[0];
+	}
+	if ($coords[$n][1]>$borders[3]) {
+	    $step[$n][1]= - $step[$n][1];
+	    $coords[$n][1] = $borders[3];
+	}
+	if ($coords[$n][1]<$borders[1]) {
+	    $step[$n][1]= - $step[$n][1];
+	    $coords[$n][1] = $borders[1];
+	}
     }
-    if ($coords[$n][0]<$borders[0]){
-      $step[$n][0]= - $step[$n][0];
-      $coords[$n][0] = $borders[0];
-    }
-    if ($coords[$n][1]>$borders[3]){
-      $step[$n][1]= - $step[$n][1];
-      $coords[$n][1] = $borders[3];
-    }
-    if ($coords[$n][1]<$borders[1]){
-      $step[$n][1]= - $step[$n][1];
-      $coords[$n][1] = $borders[1];
-    }
-  }
 }
 $command{undef_last}=sub {
   my $item = pop(@node);
@@ -104,9 +109,8 @@ $command{conn_width} = sub {
 $command{conn_colour} = sub {
   foreach(@conn){$_->colour($_->colour eq'red'?'black':'red')}
 };
-$command{'conn_free'}=sub {
-  weaken $_ for(@conn) ;
-};
+
+
 my $frame = $mw->Frame()->pack(-side=>'left');
 my $prev;
 for (sort keys %command){
